ClientConfigKey

Enum ClientConfigKey 

#[non_exhaustive]
pub enum ClientConfigKey {
Show 18 variants AllowHttp, AllowInvalidCertificates, ConnectTimeout, DefaultContentType, Http1Only, Http2KeepAliveInterval, Http2KeepAliveTimeout, Http2KeepAliveWhileIdle, Http2MaxFrameSize, Http2Only, PoolIdleTimeout, PoolMaxIdlePerHost, ProxyUrl, ProxyCaCertificate, ProxyExcludes, RandomizeAddresses, Timeout, UserAgent,
}
Configuration keys for ClientOptions

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AllowHttp

Allow non-TLS, i.e. non-HTTPS connections

Supported keys:

  • allow_http


AllowInvalidCertificates

Skip certificate validation on https connections.

Warning

You should think very carefully before using this method. If invalid certificates are trusted, any certificate for any site will be trusted for use. This includes expired certificates. This introduces significant vulnerabilities, and should only be used as a last resort or for testing

Supported keys:

  • allow_invalid_certificates


ConnectTimeout

Timeout for only the connect phase of a Client

Supported keys:

  • connect_timeout


DefaultContentType

default Content-Type for uploads

Supported keys:

  • default_content_type


Http1Only

Only use HTTP/1 connections

Supported keys:

  • http1_only


Http2KeepAliveInterval

Interval for HTTP/2 Ping frames should be sent to keep a connection alive.

Supported keys:

  • http2_keep_alive_interval


Http2KeepAliveTimeout

Timeout for receiving an acknowledgement of the keep-alive ping.

Supported keys:

  • http2_keep_alive_timeout


Http2KeepAliveWhileIdle

Enable HTTP/2 keep alive pings for idle connections

Supported keys:

  • http2_keep_alive_while_idle


Http2MaxFrameSize

Sets the maximum frame size to use for HTTP/2.

Supported keys:

  • http2_max_frame_size


Http2Only

Only use HTTP/2 connections

Supported keys:

  • http2_only


PoolIdleTimeout

The pool max idle timeout

This is the length of time an idle connection will be kept alive

Supported keys:

  • pool_idle_timeout


PoolMaxIdlePerHost

maximum number of idle connections per host

Supported keys:

  • pool_max_idle_per_host


ProxyUrl

HTTP proxy to use for requests

Supported keys:

  • proxy_url


ProxyCaCertificate

PEM-formatted CA certificate for proxy connections

Supported keys:

  • proxy_ca_certificate


ProxyExcludes

List of hosts that bypass proxy

Supported keys:

  • proxy_excludes


RandomizeAddresses

Randomize order addresses that the DNS resolution yields.

This will spread the connections across more servers.

Warning

This will override the DNS resolver configured by reqwest.

Supported keys:

  • randomize_addresses


Timeout

Request timeout

The timeout is applied from when the request starts connecting until the response body has finished

Supported keys:

  • timeout


UserAgent

User-Agent header to be used by this client

Supported keys:

  • user_agent