pub struct Certificate(/* private fields */);Expand description
Represents a CA certificate provided by the user.
This is used to configure the client to trust a specific certificate. See Self::from_pem for an example
Implementations
Sourceimpl Certificate
impl Certificate
Sourcepub fn from_pem(pem: &[u8]) -> Result<Self>
pub fn from_pem(pem: &[u8]) -> Result<Self>
Create a Certificate from a PEM encoded certificate.
Example from a PEM file
let mut buf = Vec::new();
File::open("my_cert.pem").unwrap()
.read_to_end(&mut buf).unwrap();
let cert = Certificate::from_pem(&buf).unwrap();
Sourcepub fn from_pem_bundle(pem_bundle: &[u8]) -> Result<Vec<Self>>
pub fn from_pem_bundle(pem_bundle: &[u8]) -> Result<Vec<Self>>
Create a collection of Certificate from a PEM encoded certificate
bundle.
Files that contain such collections have extensions such as .crt,
.cer and .pem files.