pub struct SpawnedReqwestConnector { /* private fields */ }Expand description
reqwest::Client connector that performs all I/O on the provided tokio
Runtime (thread pool).
This adapter is most useful when you wish to segregate I/O from CPU bound
work that may be happening on the Runtime.
Example: Spawning requests on separate runtime
// create a tokio runtime for I/O.
let io_runtime: Runtime = get_io_runtime();
// configure a store using the runtime.
let handle = io_runtime.handle().clone(); // get a handle to the same runtime
let store: Arc<dyn ObjectStore> = Arc::new(
MicrosoftAzureBuilder::new()
.with_http_connector(SpawnedReqwestConnector::new(handle))
.with_container_name("my_container")
.with_account("my_account")
.build()?
);
// any requests made using store will be spawned on the io_runtimeImplementations