DigestContext

Trait DigestContext 

pub trait DigestContext: Send {
    // Required methods
    fn update(&mut self, data: &[u8]);
    fn finish(&mut self) -> Result<&[u8]>;
}
Incrementally compute a digest, see CryptoProvider::digest

Required Methods

fn update(&mut self, data: &[u8])

Updates the digest with all the data in data.

It is implementation-defined behaviour to call this after calling Self::finish

fn finish(&mut self) -> Result<&[u8]>

Finalizes the digest calculation and returns the digest value.

It is implementation-defined behaviour to call this after calling Self::finish

Implementors