#[non_exhaustive]pub enum HttpErrorKind {
Connect,
Request,
Timeout,
Interrupted,
Decode,
Unknown,
}Expand description
Identifies the kind of HttpError
This is used, among other things, to determine if a request can be retried
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Connect
An error occurred whilst connecting to the remote
Will be automatically retried
Request
An error occurred whilst making the request
Will be automatically retried
Timeout
Request timed out
Will be automatically retried if the request is idempotent
Interrupted
The request was aborted
Will be automatically retried if the request is idempotent
Decode
An error occurred whilst decoding the response
Will not be automatically retried
Unknown
An unknown error occurred
Will not be automatically retried